# Bryan Schumaker (11/25/2010)

import ocarina
from components import button
from components import entry

gtk    = ocarina.gtk
header = None
bar    = None


def bar_add(widget, expand = False, fill = False):
	bar.pack_start(widget, expand, fill)

def init():
	global header
	global bar

	header = gtk.VBox()
	bar    = gtk.HBox()
	sep    = gtk.HSeparator()
	vsep   = gtk.VSeparator()
	vsep.show()
	header.pack_start(bar)
	header.pack_start(sep)
	header.show_all()

	bar_add(entry.FilterEntry(), True, True)
	bar_add(button.OpenButton())
	bar_add(button.SaveButton())
	bar_add(button.ExportButton())
	bar_add(vsep)
	bar_add(button.UpdateButton())
	bar_add(button.ClearButton())
	bar_add(button.GotoButton())
	bar_add(button.RandomButton())
	bar_add(button.VolumeButton())
init()
